#include <QDebug>
#include "ProcessManager.h"

ProcessManager::ProcessManager(QObject *parent)
	: QObject(parent)
	, process( new QProcess( this ) )
	, current_proc()
{
	connect( process, SIGNAL( error( QProcess::ProcessError ) )
		, this, SLOT( onError() ) );
	connect( process, SIGNAL( finished ( int, QProcess::ExitStatus ) )
		, this, SLOT( nextCurrentProc() ) );
	connect( process, SIGNAL( readyRead() )
		, this, SLOT( onReadyRead() ) );
}

ProcessManager::~ProcessManager ()
{
	if ( process->state() != QProcess::NotRunning )
	{
		process->disconnect( this );
		process->terminate();
		process->waitForFinished( 3000 );
	}
};

void ProcessManager::append ( const QString & proc_file )
{
	proc_files.append( proc_file );
}

void ProcessManager::start ()
{
	current_proc = 0;
	nextCurrentProc ();
}

void ProcessManager::nextCurrentProc ()
{
	if ( current_proc < proc_files.count() )
		process->start( proc_files.at( current_proc++ ) );
	else
		emit finished();
}

void ProcessManager::onError ()
{
	qWarning() << "Process execute error";
	emit finished();
}

void ProcessManager::onReadyRead ()
{
	emit dataInputted( process->readAll() );
};

void ProcessManager::outputData ( const QByteArray & data )
{
	process->write( data );
};
